@@ -13,6 +13,7 @@ import (
 	"github.com/abiosoft/colima/config"
 	"github.com/abiosoft/colima/config/configmanager"
 	"github.com/abiosoft/colima/environment"
+	"github.com/abiosoft/colima/environment/container/containerd"
 	"github.com/abiosoft/colima/environment/container/docker"
 	"github.com/abiosoft/colima/environment/container/kubernetes"
 	"github.com/abiosoft/colima/environment/host"
@@ -53,33 +54,59 @@ type colimaApp struct {
 	guest environment.VM
 }
 
-func (c colimaApp) Start(conf config.Config) error {
-	ctx := context.WithValue(context.Background(), config.CtxKey(), conf)
+func (c colimaApp) startWithRuntime(conf config.Config) ([]environment.Container, error) {
+	kubernetesEnabled := conf.Kubernetes.Enabled
+
+	// Kubernetes can only be enabled for docker and containerd
+	switch conf.Runtime {
+	case docker.Name, containerd.Name:
+	default:
+		kubernetesEnabled = false
+	}
+
+	var containers []environment.Container
 
 	{
 		runtime := conf.Runtime
-		if conf.Kubernetes.Enabled {
+		if kubernetesEnabled {
 			runtime += "+k3s"
 		}
-		log.Println("starting", config.CurrentProfile().DisplayName)
 		log.Println("runtime:", runtime)
 	}
-	var containers []environment.Container
+
 	// runtime
 	{
 		env, err := c.containerEnvironment(conf.Runtime)
 		if err != nil {
-			return err
+			return nil, err
 		}
 		containers = append(containers, env)
 	}
+
 	// kubernetes should come after required runtime
-	if conf.Kubernetes.Enabled {
+	if kubernetesEnabled {
 		env, err := c.containerEnvironment(kubernetes.Name)
+		if err != nil {
+			return nil, err
+		}
+		containers = append(containers, env)
+	}
+
+	return containers, nil
+}
+
+func (c colimaApp) Start(conf config.Config) error {
+	ctx := context.WithValue(context.Background(), config.CtxKey(), conf)
+
+	log.Println("starting", config.CurrentProfile().DisplayName)
+
+	var containers []environment.Container
+	if !environment.IsNoneRuntime(conf.Runtime) {
+		cs, err := c.startWithRuntime(conf)
 		if err != nil {
 			return err
 		}
-		containers = append(containers, env)
+		containers = cs
 	}
 
 	// the order for start is:
@@ -377,13 +404,17 @@ func (c colimaApp) setKubernetes(conf config.Kubernetes) error {
 
 func (c colimaApp) currentContainerEnvironments(ctx context.Context) ([]environment.Container, error) {
 	var containers []environment.Container
-
 	// runtime
 	{
 		runtime, err := c.currentRuntime(ctx)
 		if err != nil {
 			return nil, err
 		}
+
+		if environment.IsNoneRuntime(runtime) {
+			return nil, nil
+		}
+
 		env, err := c.containerEnvironment(runtime)
 		if err != nil {
 			return nil, err
@@ -435,7 +466,7 @@ func generateSSHConfig(modifySSHConfig bool) error {
 			continue
 		}
 
-		profile := config.Profile(i.Name)
+		profile := config.ProfileFromName(i.Name)
 		resp, err := limautil.ShowSSH(profile.ID)
 		if err != nil {
 			log.Trace(fmt.Errorf("error retrieving SSH config for '%s': %w", i.Name, err))
