@@ -13,18 +13,19 @@ import (
 	"github.com/abiosoft/colima/core"
 	"github.com/abiosoft/colima/daemon"
 	"github.com/abiosoft/colima/environment"
-	"github.com/abiosoft/colima/environment/container/containerd"
+	"github.com/abiosoft/colima/environment/vm/lima/limaconfig"
 	"github.com/abiosoft/colima/environment/vm/lima/limautil"
 	"github.com/abiosoft/colima/util"
 	"github.com/abiosoft/colima/util/osutil"
 	"github.com/abiosoft/colima/util/yamlutil"
 	"github.com/sirupsen/logrus"
+	yaml "gopkg.in/yaml.v3"
 )
 
 // New creates a new virtual machine.
 func New(host environment.HostActions) environment.VM {
 	// lima config directory
-	limaHome := limautil.LimaHome()
+	limaHome := config.LimaDir()
 
 	// environment variables for the subprocesses
 	var envs []string
@@ -48,10 +49,6 @@ const (
 	limactl         = limautil.LimactlCommand
 )
 
-func (l limaVM) limaConfFile() string {
-	return filepath.Join(l.limaHome, config.CurrentProfile().ID, "lima.yaml")
-}
-
 var _ environment.VM = (*limaVM)(nil)
 
 type limaVM struct {
@@ -62,7 +59,7 @@ type limaVM struct {
 	conf config.Config
 
 	// lima config
-	limaConf Config
+	limaConf limaconfig.Config
 
 	// lima config directory
 	limaHome string
@@ -90,21 +87,27 @@ func (l *limaVM) Start(ctx context.Context, conf config.Config) error {
 	})
 
 	a.Stage("creating and starting")
-	configFile := filepath.Join(os.TempDir(), config.CurrentProfile().ID+".yaml")
+	confFile := filepath.Join(os.TempDir(), config.CurrentProfile().ID+".yaml")
 
 	a.Add(func() (err error) {
 		l.limaConf, err = newConf(ctx, conf)
-		if err != nil {
-			return err
-		}
-		return yamlutil.WriteYAML(l.limaConf, configFile)
+		return err
 	})
+
+	a.Add(func() error {
+		return l.downloadDiskImage(ctx, conf)
+	})
+
+	a.Add(func() error {
+		return yamlutil.WriteYAML(l.limaConf, confFile)
+	})
+
 	a.Add(l.writeNetworkFile)
 	a.Add(func() error {
-		return l.host.Run(limactl, "start", "--tty=false", configFile)
+		return l.host.Run(limactl, "start", "--tty=false", confFile)
 	})
 	a.Add(func() error {
-		return os.Remove(configFile)
+		return os.Remove(confFile)
 	})
 
 	// adding it to command chain to execute only after successful startup.
@@ -137,10 +140,14 @@ func (l *limaVM) resume(ctx context.Context, conf config.Config) error {
 		conf = l.syncDiskSize(ctx, conf)
 
 		l.limaConf, err = newConf(ctx, conf)
-		if err != nil {
-			return err
-		}
-		return yamlutil.WriteYAML(l.limaConf, l.limaConfFile())
+		return err
+	})
+
+	a.Add(l.setDiskImage)
+
+	a.Add(func() error {
+		err := yamlutil.WriteYAML(l.limaConf, config.CurrentProfile().LimaFile())
+		return err
 	})
 
 	a.Add(l.writeNetworkFile)
@@ -244,7 +251,7 @@ func (l limaVM) Env(s string) (string, error) {
 }
 
 func (l limaVM) Created() bool {
-	stat, err := os.Stat(l.limaConfFile())
+	stat, err := os.Stat(config.CurrentProfile().LimaFile())
 	return err == nil && !stat.IsDir()
 }
 
@@ -257,6 +264,38 @@ func (l limaVM) Arch() environment.Arch {
 	return environment.Arch(a)
 }
 
+func (l *limaVM) downloadDiskImage(ctx context.Context, conf config.Config) error {
+	log := l.Logger(ctx)
+
+	if image, ok := limautil.ImageCached(l.limaConf.Arch, conf.Runtime); ok {
+		l.limaConf.Images = []limaconfig.File{image}
+		return nil
+	}
+
+	log.Infoln("downloading disk image ...")
+	image, err := limautil.DownloadImage(l.limaConf.Arch, conf.Runtime)
+	if err != nil {
+		return fmt.Errorf("error getting qcow image: %w", err)
+	}
+
+	l.limaConf.Images = []limaconfig.File{image}
+	return nil
+}
+
+func (l *limaVM) setDiskImage() error {
+	var c limaconfig.Config
+	b, err := os.ReadFile(config.CurrentProfile().LimaFile())
+	if err != nil {
+		return err
+	}
+	if err := yaml.Unmarshal(b, &c); err != nil {
+		return err
+	}
+
+	l.limaConf.Images = c.Images
+	return nil
+}
+
 func (l *limaVM) syncDiskSize(ctx context.Context, conf config.Config) config.Config {
 	log := l.Logger(ctx)
 	instance, err := limautil.InstanceConfig()
@@ -271,11 +310,6 @@ func (l *limaVM) syncDiskSize(ctx context.Context, conf config.Config) config.Co
 			return false
 		}
 
-		if conf.VMType == VZ {
-			log.Warnln("dynamic disk resize not supported for VZ driver, ignoring...")
-			return false
-		}
-
 		size := conf.Disk - instance.Disk
 		if size < 0 {
 			log.Warnln("disk size cannot be reduced, ignoring...")
@@ -305,18 +339,6 @@ func (l *limaVM) syncDiskSize(ctx context.Context, conf config.Config) config.Co
 }
 
 func (l *limaVM) addPostStartActions(a *cli.ActiveCommandChain, conf config.Config) {
-	// package dependencies
-	a.Add(func() error {
-		return l.installDependencies(a.Logger(), conf)
-	})
-
-	// containerd dependencies
-	if conf.Runtime == containerd.Name {
-		a.Add(func() error {
-			return core.SetupContainerdUtils(l.host, l, environment.Arch(conf.Arch))
-		})
-	}
-
 	// registry certs
 	a.Add(l.copyCerts)
 
@@ -354,7 +376,7 @@ func (l *limaVM) addPostStartActions(a *cli.ActiveCommandChain, conf config.Conf
 
 	// preserve state
 	a.Add(func() error {
-		if err := configmanager.SaveToFile(conf, limautil.ColimaStateFile(config.CurrentProfile().ID)); err != nil {
+		if err := configmanager.SaveToFile(conf, config.CurrentProfile().StateFile()); err != nil {
 			logrus.Warnln(fmt.Errorf("error persisting Colima state: %w", err))
 		}
 		return nil
